spannertools.get_spanners_attached_to_any_proper_child_of_component
===================================================================

.. autofunction:: abjad.tools.spannertools.get_spanners_attached_to_any_proper_child_of_component.get_spanners_attached_to_any_proper_child_of_component
